@@ -9,8 +9,8 @@
 #![feature(generic_const_exprs)]
 #![feature(const_refs_to_cell)]
 #![feature(maybe_uninit_slice)]
+#![feature(const_slice_index)]
 #![feature(const_option_ext)]
-#![feature(const_ptr_offset)]
 #![feature(const_trait_impl)]
 #![feature(const_ptr_write)]
 #![feature(core_intrinsics)]
